<?php
/*
Plugin Name: WP Ride Booking Pro
Plugin URI: https://wpridebooking.com/
Description: WP Ride Booking Pro is a perfect solution for creating an online travel agency system such as Taxi Booking, Cab Booking, Bus Booking etc.
Author: WP Ride Booking
Author URI : https://wpridebooking.com/
Text Domain: wp-ride-booking-pro
Domain Path: /wprbp-i18n/languages
Version: 1.4
Tested upto: 5.1.1
*/

define('WPRBP_FILE', basename(__FILE__));

define('WPRBP_NAME', str_replace('.php', '', WPRBP_FILE));

define('WPRBP_PATH', plugin_dir_path(__FILE__));

define('WPRBP_URL', plugin_dir_url(__FILE__));

include_once( WPRBP_PATH . 'includes/shortcodes.php' );
include_once( WPRBP_PATH . 'includes/ride-functions.php' );

function wprb_ride_booking_pro_load_textdomain() {
	$domain = 'wp-ride-booking-pro';
	$locale = apply_filters( 'plugin_locale', get_locale(), $domain );
	// wp-content/languages/plugin-name/plugin-name-de_DE.mo
	load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' );
	// wp-content/plugins/plugin-name/languages/plugin-name-de_DE.mo
	load_plugin_textdomain( $domain, FALSE, basename( dirname( __FILE__ ) ) . '/wprbp-i18n/languages/' );

}
add_action( 'init', 'wprb_ride_booking_pro_load_textdomain' );


function wprb_ride_booking_pro_ajaxurl() { ?>
<script type="text/javascript">
var wprbp_ajaxurl = '<?php echo admin_url('admin-ajax.php'); ?>';
</script>
<?php
	$distance_unit = get_option("ride_distance_unit");
    if($distance_unit=='mile'){
        echo "<script>var d_unit = 'IMPERIAL';</script>";
    }
    else{
        echo "<script>var d_unit = 'METRIC';</script>";
    }
}
add_action('wp_head','wprb_ride_booking_pro_ajaxurl');

function wprb_ride_booking_pro_load_dashicons() {
wp_enqueue_style( 'dashicons' );
}
add_action( 'wp_enqueue_scripts', 'wprb_ride_booking_pro_load_dashicons' );

function wprb_ride_booking_pro_custom_css() {
  echo '<style>
 .wprbp_settings {
   	width: 100%;
	padding: 10px 0;
}

.wprbp_settings tbody tr{
	height:50px;
}

.wprbp_settings tbody tr td input[type="text"]{
	padding-bottom: 8px;
    padding-top: 8px;
    width: 100%;
}
.ride_seting_form .wp-picker-container {
	position: relative;
}

.ride_seting_form .wp-picker-holder {
	position: absolute;
	z-index: 9;
}
.wprbp-color-picker { padding:2px 5px!important;}

form.ride_seting_form h1{
margin-top:50px;
}
</style>';
}
add_action('admin_head', 'wprb_ride_booking_pro_custom_css');

function wprb_ride_booking_pro_scripts() {
    $api_key_js = get_option('google_map_api');		
	wp_enqueue_script( 'jquery-ui-new', '//ajax.googleapis.com/ajax/libs/jqueryui/1.10.3/jquery-ui.min.js',array('jquery'));
	wp_enqueue_script('bootstrap-script', WPRBP_URL.'js/bootstrap.min.js', array('jquery'));
	wp_enqueue_script('bootstrap-datetimepicker-script', WPRBP_URL.'js/bootstrap-datetimepicker.min.js', array('jquery'));;
	wp_enqueue_script( 'wprbp-map-jscript', '//maps.googleapis.com/maps/api/js?libraries=places&key='.$api_key_js, array('jquery'));
	wp_enqueue_script( 'wprbp-ride-jscript', WPRBP_URL . 'includes/distance.js', array('jquery') );

	wp_localize_script( 'wprbp-ride-jscript', 'objectL10n', array(
		'viewcart' => esc_html__( 'View cart', 'wp-ride-booking-pro' )
	) );
	wp_enqueue_style( 'wprbp-map-style', WPRBP_URL . 'css/wprbp-style.css');
	wp_enqueue_style( 'bootstrap-datetimepicker.min', WPRBP_URL . 'css/bootstrap-datetimepicker.min.css');
	wp_enqueue_style( 'jquery-ui-new-style', '//code.jquery.com/ui/1.11.0/themes/smoothness/jquery-ui.css');
}
add_action( 'wp_enqueue_scripts', 'wprb_ride_booking_pro_scripts' );

function wprbp_add_color_picker( $hook ) {
    if( is_admin() ) { 
        // Add the color picker css file       
        wp_enqueue_style( 'wp-color-picker' ); 

        // Include our custom jQuery file with WordPress Color Picker dependency
        wp_enqueue_script( 'wprbp_script-handle', plugins_url( 'js/wprbp-colorpicker.js', __FILE__ ), array( 'wp-color-picker' ), false, true ); 
		
        wp_enqueue_script("wprbp-admin-script",plugins_url( 'js/wprbp-admin.js', __FILE__ ), array( 'jquery' ), false, true );
    }
}
add_action( 'admin_enqueue_scripts', 'wprbp_add_color_picker' );


function wprb_ride_booking_pro_load() {
    /* do stuff once right after activation */
    if (is_admin() && get_option('Activated_Plugin') == 'wp-ride-booking-pro') {
        delete_option( 'Activated_Plugin' );

        if (!class_exists('WooCommerce')) {
            add_action('admin_notices', 'wprbp_plugin_notice');

            //Deactivate our plugin
            deactivate_plugins(plugin_basename(__FILE__));

            if (isset($_GET['activate'])) {
                unset($_GET['activate']);
            }
        }
    }
}
add_action('admin_init', 'wprb_ride_booking_pro_load');

function wprbp_plugin_notice() {
echo '<div class="error"><p>'.__("Please install and activate woocomemrce plugin before activating this plugin.","wp-ride-booking-pro").'</p></div>';
}

function wprb_ride_booking_pro_install() {
	add_option('Activated_Plugin', 'wp-ride-booking-pro');
		$product_id = get_option('ride_product_id');

		if(!$product_id){
            $post_id = wp_insert_post( array(
    		'post_title' => 'WP Ride Booking',
    		'post_content' => __('Compulsory product for WP Ride Booking Pro Plugin to work','wp-ride-booking-pro'),
    		'post_status' => __('publish','wp-ride-booking-pro'),
    		'post_type' => "product",
		) );

        }else{
            $post_id = $product_id;
        }

		update_option("ride_booking_product",$post_id);

		wp_set_object_terms( $post_id, 'simple', 'product_type' );

		update_post_meta( $post_id, '_regular_price', '0' );

		update_post_meta( $post_id, '_visibility', 'visible' );

		update_post_meta( $post_id, '_stock_status', 'instock');

		update_post_meta( $post_id, '_manage_stock', 'no' );

		update_post_meta( $post_id, '_price', '0' );

		update_option('ride_header_footer_bg_color','#a52a2a');

		update_option('ride_text_color','#ffffff');

		update_option('ride_submit_button_bg_color','#3D3D3D');

		update_option('ride_button_bg_hover_color','#000000');

		update_option('ride_product_id',$post_id);

}
register_activation_hook( __FILE__, 'wprb_ride_booking_pro_install' );

function wprb_ride_booking_pro_activate() {
add_menu_page('WP Ride Booking Pro','Ride Booking Pro','administrator', 'wp-ride-booking-pro', 'wprb_booking_pro_setting', plugins_url( 'images/taxi.png',__FILE__ ));
}
add_action( 'admin_menu', 'wprb_ride_booking_pro_activate' );

function wprb_booking_pro_setting(){
	if(isset($_POST['wprbp_setting_submit'])){
		$product_id = get_option('ride_product_id');

		$map_api = sanitize_text_field($_POST['map_api']);

		$map_height = sanitize_text_field($_POST['map_height']);

		$distance_unit = sanitize_text_field($_POST['distance_unit']);

		$ride_rate = (float) $_POST['ride_rate'];

		$button_txt = sanitize_text_field($_POST['button_txt']);	

		$header_footer_bg_color = sanitize_text_field($_POST['header_footer_bg_color']);

		$ride_text_color = sanitize_text_field($_POST['ride_text_color']);

		$submit_button_bg_color = sanitize_text_field($_POST['submit_button_bg_color']);

		$button_bg_hover_color = sanitize_text_field($_POST['button_bg_hover_color']);

		$product_title = sanitize_text_field($_POST['product-title']);

		$product_description = sanitize_text_field($_POST['product-description']);

		$product_base_price = $_POST['product-base-price'];

		$product_array = array(
			'ID' => $product_id,
			'post_title' => $product_title,
			'post_content' => $product_description,
			'post_type' => 'product'
		);

		wp_update_post( $product_array );

		update_post_meta($product_id,'_price',$product_base_price);

		update_post_meta($product_id,'_regular_price',$product_base_price);

		update_option("google_map_api",sanitize_text_field($map_api));

		update_option('ride_map_height', sanitize_text_field($map_height));

		update_option("ride_distance_unit",$distance_unit);

		update_option("per_distance_rate",$ride_rate);

		update_option("ride_distance_unit",$distance_unit);

		update_option("calculate_button_txt",sanitize_text_field($button_txt));

		update_option('ride_header_footer_bg_color', sanitize_text_field($header_footer_bg_color));

		update_option('ride_text_color', sanitize_text_field($ride_text_color));

		update_option('ride_submit_button_bg_color', sanitize_text_field($submit_button_bg_color));

		update_option('ride_button_bg_hover_color', sanitize_text_field($button_bg_hover_color));

	}	

		$api_key = esc_attr(get_option('google_map_api'));

		$distance_unit_new = esc_attr(get_option('ride_distance_unit'));

		$map_height_new = esc_attr(get_option('ride_map_height'));

		$ride_rate = get_option('per_distance_rate');

		$button_txt = esc_attr(get_option('calculate_button_txt'));

		$header_footer_bg_color_new = esc_attr(get_option('ride_header_footer_bg_color'));

		$ride_text_color_new = esc_attr(get_option('ride_text_color'));

		$submit_button_bg_color_new = esc_attr(get_option('ride_submit_button_bg_color'));

		$ride_button_bg_hover_color = esc_attr(get_option('ride_button_bg_hover_color'));
	?>

	<form method="post" class="ride_seting_form"><table class="wprbp_settings"><h1><?php _e('WP Ride Booking Setting','wp-ride-booking-pro');?></h1>
	<tr>
		<td valign="top" width="50%">
			<table width="90%">
				<tr><td><strong><?php _e('Google Map API Key', 'wp-ride-booking-pro');?></strong></td><td><input type="text" name="map_api" id="map_api" value="<?php echo esc_attr($api_key);?>"></td></tr>
				<tr><td><strong><?php _e('Google Map Height', 'wp-ride-booking-pro');?></strong></td><td><select name="map_height">
				<?php $selected = (isset( $map_height_new ) &&  $map_height_new === '300') ? 'selected' : '' ; ?>
				 <option value="300" <?php echo $selected;?>>300px</option>
				 <?php $selected = (isset( $map_height_new ) &&  $map_height_new === '400') ? 'selected' : '' ; ?>
				 <option value="400" <?php echo $selected;?>>400px</option>
				 <?php $selected = (isset( $map_height_new ) &&  $map_height_new === '500') ? 'selected' : '' ; ?>
				 <option value="500" <?php echo $selected;?>>500px</option>
				 <?php $selected = (isset( $map_height_new ) &&  $map_height_new === '600') ? 'selected' : '' ; ?>
				 <option value="600" <?php echo $selected;?>>600px</option>
				 <?php $selected = (isset( $map_height_new ) &&  $map_height_new === '700') ? 'selected' : '' ; ?>
				 <option value="700" <?php echo $selected;?>>700px</option></select></td></tr>

				<tr>
			    <td><strong><?php _e('Distance Unit', 'wp-ride-booking-pro');?></strong></td>
			    <td><select name="distance_unit" id="distance_unit">
			    <?php $du_selected = (isset( $distance_unit_new ) &&  $distance_unit_new === 'kilometer') ? 'selected' : '' ; ?>
				 <option value="kilometer" <?php echo $du_selected;?>>kilometers</option>
				 
				 <?php $du_selected = (isset( $distance_unit_new ) &&  $distance_unit_new === 'mile') ? 'selected' : '' ; ?>
				 <option value="mile" <?php echo $du_selected;?>>miles</option>
			         </select></td>
			    </tr>

			    <tr><td><strong><?php _e('Per ', 'wp-ride-booking-pro');?><span id="selected_unit"><?php _e($distance_unit_new,'wp-ride-booking-pro');?></span><?php _e(' rate','wp-ride-booking-pro');?> (<?php echo get_woocommerce_currency();?>)</strong></td><td><input type="text" name="ride_rate" id="ride_rate" value="<?php echo $ride_rate;?>"></td></tr>
			  
				<tr><td><strong><?php _e('Submit Button Text', 'wp-ride-booking-pro');?></strong></td><td><input type="text" name="button_txt" id="button_txt" value="<?php if(isset($button_txt)){ echo $button_txt; }?>"></td></tr>
			</table>
		</td>
		<td valign="top" width="50%">
			<table width="80%">
				<tr><td valign="top"><strong><?php _e('Header / Footer Background Color', 'wp-ride-booking-pro');?></strong></td><td valign="top"><input type="text" name="header_footer_bg_color" value="<?php esc_attr_e($header_footer_bg_color_new); ?>" class="wprbp-color-picker"></td></tr>

				<tr><td valign="top"><strong><?php _e('Text Color', 'wp-ride-booking-pro');?></strong></td><td valign="top"><input type="text" name="ride_text_color" value="<?php esc_attr_e($ride_text_color_new); ?>" class="wprbp-color-picker"></td></tr>

				<tr><td valign="top"><strong><?php _e('Submit Button Background Color', 'wp-ride-booking-pro');?></strong></td><td valign="top"><input type="text" name="submit_button_bg_color" value="<?php esc_attr_e($submit_button_bg_color_new); ?>"  class="wprbp-color-picker"></td></tr>

				<tr><td valign="top"><strong><?php _e('Button Background Hover Color', 'wp-ride-booking-pro');?></strong></td><td valign="top"><input type="text" name="button_bg_hover_color" value="<?php esc_attr_e($ride_button_bg_hover_color); ?>" class="wprbp-color-picker"></td></tr>

			</table>
		</td>
	</tr>
	<tr>
		<td valign="top">
			<table width="90%">
				<tr><td colspan="2"><h2><strong><?php _e('Woocommerce default product settings', 'wp-ride-booking-pro');?></strong></h2></td></tr>
				<?php global $post; $product_id = get_option('ride_product_id'); 
				$product_title = get_the_title($product_id); ?>
				<tr><td><strong><?php _e('Product Title', 'wp-ride-booking-pro');?></strong></td><td><input type="text" name="product-title" id="product-title" value="<?php echo esc_attr($product_title); ?>"></td></tr>

				<?php $product_description = get_post_field('post_content',$product_id); ?>
				<tr><td><strong><?php _e('Product Description', 'wp-ride-booking-pro');?></strong></td><td><textarea style="width:100%;" name="product-description" id="product-description"><?php esc_attr_e( $product_description, 'wp-ride-booking-pro' )?></textarea> </td></tr>

				<?php $base_price = get_post_meta($product_id,'_price',true);?>
				<tr><td><strong><?php _e('Product Base Price', 'wp-ride-booking-pro');?></strong></td><td><input type="number" min="0" name="product-base-price" id="product-base-price" value="<?php esc_attr_e( $base_price, 'wp-ride-booking-pro' );?>"></td></tr>

				<tr><td colspan="2" style="margin-top:15px; display:inline-block;"><input type="submit" name="wprbp_setting_submit" value="<?php esc_attr_e( 'Save changes', 'wp-ride-booking-pro' ); ?>" class="button button-primary"></td></tr>
			</table>
		</td>
		<td></td>
	</tr>
	</form>
	<?php 
}